# TODO: Add a docstring here
from citrine.citrine import Citrine  # noqa: F401
import logging

logging.basicConfig(level=logging.WARNING)
